<?php

	/**
	* Zopim module for Interspire Shopping Cart. To enable
	* this module in Interspire Shopping Cart login to the control panel and click the
	* Settings -> Analytics Settings tab in the menu.
	*
	* Created [Feb 17th 2011]
	* - Provides specific module for zopim chat/tracking code
	* - If customer logged in, name and email information auto-populated to speed up comms/context
	*/
	class ANALYTICS_ZOPIM extends ISC_ANALYTICS
	{

		/*
			Analytics class constructor
		*/
		public function __construct()
		{

			// Setup the required variables for the Google analytics module
			parent::__construct();

			$this->_name = GetLang('ZopimName');
			$this->_image = "zopimlogo.gif";
			$this->_description = GetLang('ZopimDesc');
			$this->_help = GetLang('ZopimHelp');
			$this->_height = 0;
		}

		/**
		* Custom variables for the analytics module. Custom variables are stored in the following format:
		* array(variable_id, variable_name, variable_type, help_text, default_value, required, [variable_options], [multi_select], [multi_select_height])
		* variable_type types are: text,number,password,radio,dropdown
		* variable_options is used when the variable type is radio or dropdown and is a name/value array.
		*/
		public function SetCustomVars()
		{

			$this->_variables['trackingcode'] = array(
				"name" => "Tracking Code",
				"type" => "textarea",
				"help" => GetLang('ZopimCodeHelp'),
				"default" => "",
				"required" => true,
				"rows" => 7
			);
		}

		/*
		* Return the tracking code for this analytics module.
		*/

		public function GetTrackingCode()
		{

			/*
			 * We have to return the main widget code BEFORE any API customisation
			 */
			$trackingCode = $this->GetValue("trackingcode");
			
			/*
			 * Now we can prefill out the information for this customer (if they're logged in)
			 * which will make it easier for us to respond to any queries or problems 
			 */
			if(!empty($GLOBALS['CurrentCustomerFirstName']) || !empty($GLOBALS['CurrentCustomerLastName'])) {
				
				$trackingCode .= <<<EOF
<script type="text/javascript">
$(function(){
	if (typeof \$zopim != 'undefined') {
		\$zopim.livechat.set({
			name: '{$GLOBALS['CurrentCustomerFirstName']} {$GLOBALS['CurrentCustomerLastName']}',
			email: '{$GLOBALS['CurrentCustomerEmail']}'
		});
	}
});
</script>
EOF;
			}
			
			return $trackingCode;
		}

        /**
         * Return the conversion tracking code for this module.
         */
        public function GetConversionCode()
        {
			// Nothing to do.
        } 
	}